@@ -124,10 +124,31 @@ GUI::GUI( Config & config, MidiController & mc, VoiceAllocationUnit & vau,
 	aboutDlg.set_version (VERSION);
 	aboutDlg.set_comments ("Analogue Modelling SYNTHesizer");
 	aboutDlg.set_website ("http://amsynthe.sourceforge.net/amSynth");
-	aboutDlg.set_copyright ("(C) 2002 - 2005 Nick Dowell and others");
+	std::string build_year(__DATE__, sizeof(__DATE__) - 5, 4);
+	aboutDlg.set_copyright ("(C) 2002 - " + build_year + " Nick Dowell and others");
 	Glib::RefPtr<Gdk::PixbufLoader> ldr = Gdk::PixbufLoader::create();
 	ldr->write (amsynth_logo, sizeof(amsynth_logo)); ldr->close ();
 	aboutDlg.set_logo (ldr->get_pixbuf());
+	aboutDlg.signal_response().connect(sigc::hide(mem_fun(aboutDlg, &Gtk::Dialog::hide)));
+	std::list<std::string> about_authors;
+	about_authors.push_back("Nick Dowell");
+	about_authors.push_back("Karsten Wiese");
+	about_authors.push_back("Jezar at dreampoint");
+	about_authors.push_back("Sebastien Cevey");
+	about_authors.push_back("Taybin Rutkin");
+	about_authors.push_back("Bob Ham"); 
+	about_authors.push_back("Darrick Servis");
+	about_authors.push_back("Johan Martinsson");
+	about_authors.push_back("Andy Ryan");
+	about_authors.push_back("Chris Cannam");
+	about_authors.push_back("Paul Winkler");
+	about_authors.push_back("Adam Sampson");
+	about_authors.push_back("Martin Tarenskeen");
+	about_authors.push_back("Adrian Knoth");
+	aboutDlg.set_authors(about_authors);
+	std::list<std::string> about_artists;
+	about_artists.push_back("Saul Cross");
+	aboutDlg.set_artists(about_artists);
 	
 	
 	//
@@ -362,7 +383,7 @@ GUI::init()
 	
 	statusBar.pack_start (*manage(new Gtk::VSeparator), PACK_SHRINK);
 	
-	static char cstr[10];
+	static char cstr[32];
 	sprintf( cstr, "Sample Rate: %d", config->sample_rate );
 	statusBar.pack_start (*manage(new Gtk::Label (cstr)), PACK_SHRINK, padding);
 
@@ -378,6 +399,36 @@ GUI::init()
 	
 	show_all();
 	
+	bool bad_config = false;
+	
+	if (config->current_audio_driver.empty())
+	{
+		bad_config = true;
+		MessageDialog dlg (*this, "amSynth configuration error", false, MESSAGE_ERROR, BUTTONS_OK, true);
+		dlg.set_secondary_text(
+			"amSynth could not initialise the selected audio device.\n\n"
+			"Please review the configuration and restart"
+		    );
+		dlg.run();
+	}
+	
+	if (config->current_midi_driver.empty())
+	{
+		bad_config = true;
+		MessageDialog dlg (*this, "amSynth configuration error", false, MESSAGE_ERROR, BUTTONS_OK, true);
+		dlg.set_secondary_text(
+			"amSynth could not initialise the selected midi device.\n\n"
+			"Please review the configuration and restart"
+		    );
+		dlg.run();
+	}
+	
+	if (bad_config)
+	{
+		// open config dialog
+		event_handler(evConfig);
+		return;
+	}
 	
 	// show realtime warning message if necessary
 	if (!config->realtime && config->current_audio_driver != "jack" && config->current_audio_driver != "JACK")
@@ -680,3 +731,11 @@ void GUI::GdkInputFunction(gpointer data, gint source, GdkInputCondition conditi
 	if (read (source, &req, sizeof(Request)) == sizeof(Request)) req.slot();
 
 }
+
+void ShowModalErrorMessage(const string & msg)
+{
+	MessageDialog dlg ("amSynth", false, MESSAGE_ERROR, BUTTONS_OK, true);
+	dlg.set_secondary_text(msg);
+	dlg.run();
+}
+
