@@ -1,5 +1,5 @@
 /* amSynth
- * (c) 2001-2003 Nick Dowell
+ * (c) 2001-2005 Nick Dowell
  */
 
 #ifndef _JACK_OUTPUT_H
@@ -10,38 +10,46 @@
 #endif
 
 #include "AudioOutput.h"
-#include "VoiceBoard/Synth--.h"
 #include "Config.h"
 
 class JackOutput : public GenericOutput {
 
 public:
-//			JackOutput	( );
+				JackOutput	( );
 	virtual		~JackOutput	( ) {};
-	void		setInput	( NFSource & source );
 	
-	int		init		( Config & config );// returns 0 on success
-	void		run		( );
-	void		stop		( );
+	int			init		( Config & config );// returns 0 on success
+	bool		Start		();
+	void		Stop		();
 	
 	string		get_error_msg	( )		{ return error_msg; };
 	
-	int		canRecord	( )		{ return 0; };
-	void		startRecording	( );
-	void		stopRecording	( );
+	bool		canRecord	( )		{ return false; };
 	void		setOutputFile	( string file )	{ wavoutfile = file; };
 	string		getOutputFile	( )		{ return wavoutfile; };
 
 	const char*	getTitle	( )	{ return client_name.c_str(); };
 
+#ifdef with_jack
+	int			process		(jack_nframes_t nframes);
+	int			bufsize		(jack_nframes_t nframes);
+	int			srate		(jack_nframes_t nframes);
+	void		shutdown	();
+#endif
 private:
 	int	running;
 	int	channels;
 	Config	*config;
 	string	wavoutfile;
 	int	recording;
-	int	bufsize, srate;
 	string	client_name, error_msg;
+#ifdef with_jack
+	jack_port_t 	*l_port, *r_port;
+	jack_client_t 	*client;
+#endif
+	int		sample_rate;
+	int		buf_size;
+	bool	initialised;
 };
 
-#endif				// _AUDIO_OUTPUT_H
+#endif				// _JACK_OUTPUT_H
