@@ -4,8 +4,11 @@
 
 #include "Parameter.h"
 
+#include <cstdlib>
+
 #ifdef _DEBUG
 #include <iostream>
+using namespace std;
 #endif
 
 Parameter::Parameter	(string name, Param id, float value, float min, float max, float inc, ControlType type, float base, float offset, string label)
