@@ -25,6 +25,8 @@
 #include <unistd.h>
 #include <sys/time.h>
 #include <sys/resource.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 
 using namespace std;
@@ -121,18 +123,27 @@ void install_default_files_if_reqd()
 	char * data_dir = br_find_data_dir (DEFAULT_PREFIX"/share");
 	char * amsynth_data_dir = br_strcat (data_dir, "/amSynth");
 	char * factory_controllers = br_strcat (amsynth_data_dir, "/Controllersrc");
+	char * factory_config = br_strcat (amsynth_data_dir, "/rc");
 	char * factory_bank = br_strcat (amsynth_data_dir, "/presets");
 	char * user_controllers = br_strcat (homedir, "/.amSynthControllersrc");
+	char * user_config = br_strcat (homedir, "/.amSynthrc");
 	char * user_bank = br_strcat (homedir, "/.amSynth.presets");
 	
-	if (fopen (user_controllers,"r") == NULL)
+	struct stat st;
+	
+	if (stat (user_controllers, &st) == -1)
 	{
-		printf ("installing default controller map\n");
+		printf ("installing default controller map to %s\n", user_controllers);
 		fcopy (user_controllers, factory_controllers);
 	}
-	if (fopen (user_bank,"r") == NULL)
+	if (stat (user_config, &st) == -1)
 	{
-		printf ("installing default sound bank\n");
+		printf ("installing configuration file to %s\n", user_config);
+		fcopy (user_config, factory_config);
+	}
+	if (stat (user_bank, &st) == -1)
+	{
+		printf ("installing default sound bank to %s\n", user_bank);
 		fcopy (user_bank, factory_bank);
 	}
 
@@ -147,16 +158,60 @@ void install_default_files_if_reqd()
 
 void ptest ();
 
+GenericOutput * open_audio()
+{	
+#if	__APPLE__
+
+	return CreateCoreAudioOutput();
+	
+#else
+
+	if (config.audio_driver == "jack" ||
+		config.audio_driver == "auto")
+	{
+		JackOutput *jack = new JackOutput();
+		if (jack->init(config) == 0)
+			return jack;
+		else
+		{
+			std::string jack_error = jack->get_error_msg();
+			delete jack;
+			
+			// we were asked specifically for jack, so don't use anything else
+			if (config.audio_driver == "jack") {
+				std::cerr << "JACK init failed: " << jack_error << "\n";
+				return new NullAudioOutput;
+			}
+		}
+	}
+	
+	return new AudioOutput();
+	
+#endif
+}
+
+void fatal_error(const std::string & msg)
+{
+	std::cerr << msg << "\n";
+	ShowModalErrorMessage(msg);
+	exit(1);
+}
+
 int main( int argc, char *argv[] )
 {
-	std::cout << 
-"amSynth " VERSION "\n\
-Copyright 2001-2006 Nick Dowell and others.\n\
-amSynth comes with ABSOLUTELY NO WARRANTY\n\
-This is free software, and you are welcome to redistribute it\n\
-under certain conditions; see the file COPYING for details\n";
+	Gtk::Main kit( &argc, &argv ); // this can be called SUID
+	
+	// will need to change when we reach the year 10000 ;-)
+	std::string build_year(__DATE__, sizeof(__DATE__) - 5, 4);
+	
+	std::cout <<
+		"amSynth " VERSION "\n"
+		"Copyright 2001-" << build_year << " Nick Dowell and others.\n"
+		"amSynth comes with ABSOLUTELY NO WARRANTY\n"
+		"This is free software, and you are welcome to redistribute it\n"
+		"under certain conditions; see the file COPYING for details\n";
 
-	bool jack = false;
+	// bool jack = false;
 	
 	int opt;
 	while( (opt=getopt(argc, argv, "vhstdzm:c:a:r:p:b:"))!= -1 ) {
@@ -196,58 +251,23 @@ under certain conditions; see the file COPYING for details\n";
 	// subsystem initialisation
 	//
 	
-	PresetController *presetController;
-	MidiController *midi_controller;
-	MidiInterface* midi_interface;
-	VoiceAllocationUnit *vau;
-	GenericOutput *out;
-	GUI *gui;
+	PresetController *presetController = NULL;
+	MidiController *midi_controller = NULL;
+	MidiInterface *midi_interface = NULL;
+	VoiceAllocationUnit *vau = NULL;
+	GenericOutput *out = NULL;
+	GUI *gui = NULL;
 	
 	presetController = new PresetController();
 	
-	
-	//
-	// initialise audio
-	//
-	if (config.debug_drivers) std::cerr << "\n\n*** INITIALISING AUDIO ENGINE...\n";
-	
-#if	__APPLE__
-	out = CreateCoreAudioOutput();
-#else
-	if (config.audio_driver=="jack"||config.audio_driver=="JACK")
-	{
-		jack = 1;
-		out = new JackOutput();
-		if (((JackOutput*)out)->init (config)!=0)
-		{
-			std::cerr << ((JackOutput*)out)->get_error_msg() << "\n";
-			std::cerr << "** failed to initialise JACK... aborting :'( **\n";
-			exit (10);
-		}
-	}
-	else if (config.audio_driver=="auto"||config.audio_driver=="AUTO")
-	{
-		jack = 1;
-		out = new JackOutput();
-		if (((JackOutput*) out)->init (config) != 0)
-		{
-			delete out;
-			jack = 0;
-			out = new AudioOutput();
-		}
-	}
-	else
-	{
-		out = new AudioOutput();
-	}
-	if ((!jack) && (out->init (config) != 0))
-	{
-		std::cerr << "failed to open any audio device\n\n";
-		exit (-1);
-	}
-#endif
+	out = open_audio();
+	if (!out)
+		fatal_error("Fatal Error: open_audio() returned NULL.\n"
+		            "config.audio_driver = " + config.audio_driver);
+
+	// errors now detected & reported in the GUI
+	out->init(config);
 
-	
 	vau = new VoiceAllocationUnit;
 	vau->SetSampleRate (config.sample_rate);
 	vau->SetMaxVoices (config.polyphony);
@@ -255,7 +275,8 @@ under certain conditions; see the file COPYING for details\n";
 	
 	presetController->loadPresets(config.current_bank_file.c_str());
 	
-	out->Start ();
+	// errors now detected & reported in the GUI
+	out->Start();
 	
 	if (config.debug_drivers) std::cerr << "*** DONE :)\n";
 
@@ -271,12 +292,10 @@ under certain conditions; see the file COPYING for details\n";
 	
 	midi_interface = new MidiInterface();
 #endif
-	if (midi_interface->open(config) != 0)
-	{
-		std::cerr << "couldn't to open a midi device\n\n";
-		exit (-1);
-	}
-
+	
+	// errors now detected & reported in the GUI
+	midi_interface->open(config);
+	
 	midi_controller = new MidiController( config );
 	midi_interface->SetMidiStreamReceiver(midi_controller);
 	midi_interface->Run();
@@ -293,10 +312,8 @@ under certain conditions; see the file COPYING for details\n";
   
 	presetController->getCurrentPreset().AddListenerToAll (vau);
 
-	Gtk::Main kit( &argc, &argv ); // this can be called SUID
-
 	// give audio/midi threads time to start up first..
-	if (jack) sleep (1);
+	// if (jack) sleep (1);
 
 	// this can be called SUID:
 	int gdk_input_pipe[2];
@@ -322,7 +339,6 @@ under certain conditions; see the file COPYING for details\n";
 
 	presetController->savePresets(config.current_bank_file.c_str ());
 	midi_controller->saveConfig();
-	config.save();
 	
 	out->Stop ();
 #ifdef _DEBUG
